Modules
- addons
- api
- The API module contains the public API for external libraries to consume.
- cargo
- Utilities for working with Rust/Cargo projects.
- command_
runner - Utilities for executing external programs in structures that are easy to test.
- config
- download_
client - file_
sync - gdextension_
config - Utilities for generating a
.gdextensionfile for Godot. - git
- github
- godot
- godot_
version - installer
- logging
- migrate
- Utilities for data directory migration between versions of gdenv
- path_
extension - Utilities for working with paths.
- project_
specification